@@ -11,7 +11,7 @@
 #' #Getting the ggrasp object
 #' Enter.tree <- ggrasp.load(system.file("extdata", "Enter.kSNP.tree", package="ggrasp"), 
 #' file.format = "tree", rank.file =system.file("extdata", "Enter.kSNP.ranks", package="ggrasp"));
-#' \donttest{Enter.tree.cluster <- ggrasp.cluster(Enter.tree)}
+#' \\donttest{Enter.tree.cluster <- ggrasp.cluster(Enter.tree)}
 #'
 #' #Default examples: using the initizalized ggrasp object will 
 #' #write the newick tree string to "tree.nwk"
@@ -20,7 +20,7 @@
 #' # Using the clustered ggrasp object will write a text file with the clusters saved as an ITOL clade
 #' # In conjecture with the phylogeny, this is readable by 
 #' # ITOL web phylogeny visualizer (http://itol.embl.de/) 
-#' \donttest{ggrasp.write(Enter.tree.cluster, type="itol", file=file.path(tempdir(), "tree.itol.clade.txt"));}
+#' \\donttest{ggrasp.write(Enter.tree.cluster, type="itol", file=file.path(tempdir(), "tree.itol.clade.txt"));}
 #
 #' @export
 
@@ -230,20 +230,20 @@ ggrasp.write <- function(x, file, type, rank.level)
 #' #Getting the ggrasp object
 #' Enter.tree <- ggrasp.load(system.file("extdata", "Enter.kSNP.tree", package="ggrasp"), 
 #' file.format = "tree", rank.file =system.file("extdata", "Enter.kSNP.ranks", package="ggrasp"));
-#' \donttest{Enter.tree.cluster <- ggrasp.cluster(Enter.tree)}
+#' \\donttest{Enter.tree.cluster <- ggrasp.cluster(Enter.tree)}
 #'
 #' #Default examples: using the initizalized ggrasp object will print the newick tree string 
 #' print(Enter.tree);
 #' 
 #' # Using the clustered ggrasp object will print the medoids and their respective clusters
-#' \donttest{print(Enter.tree.cluster)}
+#' \\donttest{print(Enter.tree.cluster)}
 #
 #' #Below are examples of using different output formats and rank levels
-#' \donttest{print(Enter.tree.cluster, "tree")}
+#' \\donttest{print(Enter.tree.cluster, "tree")}
 # Making a table with all the medoids and top-ranked genomes that are non-medoids
-#' \donttest{print(Enter.tree.cluster, "table", 1)}
+#' \\donttest{print(Enter.tree.cluster, "table", 1)}
 # Making a table with all genomes independent of rank
-#' \donttest{print(Enter.tree.cluster, "table", 0)}
+#' \\donttest{print(Enter.tree.cluster, "table", 0)}
 
 #' @method print ggrasp
 #' @export
@@ -597,7 +597,7 @@ summary.ggrasp <- function(object, ...)
     tmp <- rownames(con.dist)[rowSums(con.dist==max(con.dist))>0];
     phy1 = .root_midpoint(phy1)
   }
-  if (!is.binary(phy1))
+  if (!is.binary.tree(phy1))
   {
 	phy1 <- multi2di(phy1);
   }
